@@ -16,7 +16,7 @@ File inputs.yaml must contain paths to all input labels in the workflow.
 """
 
 import argparse
-import os.path
+from os import path, remove
 from sys import exit
 from bioblend.galaxy import GalaxyInstance
 from bioblend import ConnectionError
@@ -194,8 +194,8 @@ def main():
 
         # Produce tool versions file
         produce_versions_file(gi=gi, workflow_from_json=wf_from_json,
-                              path="{}/software_versions_galaxy.txt".format(args.output_dir))
-
+                              table_path="{}/software_versions_galaxy.txt".format(args.output_dir))
+        
         # wait for a little while and check if the status is ok
         logging.info("Waiting for results to be available...")
         logging.info("...in the mean time, you can check {}/histories/view?id={} for progress."
@@ -302,5 +302,3 @@ def main():
 if __name__ == '__main__':
     main()
 
-
-
